@@ -1,11 +1,14 @@
 from abc import abstractmethod
-from typing import Union, List, Dict
 
 
 class Symbol(object):
 
     @abstractmethod
-    def get_provider_args(self) -> Union[List, Dict]:
+    def fetch_price_history(self, period: str = 'max', **kwargs):
+        raise NotImplemented
+
+    @abstractmethod
+    def fetch_option_chain(self, max_maturities=None):
         raise NotImplemented
 
 
